Standar Survey — Euphorie

# Algemene MKB RI&E

Download Print

## 1 Elk gebouw"

#### 1.1 Het gebouw wordt goed onderhouden.

Enkele voorbeelden. Er zijn geen kierende kozijnen en ramen, er is geen bladderende verf aan de muren en plafonds, en er is goed hang- en sluitwerk aanwezig.

> xxxHet gebouw wordt goed onderhouden.

#### 1.2 Het interieur van het gebouw wordt goed schoongemaakt.

> xxxHet interieur van het gebouw wordt goed schoongemaakt.

#### 1.3 De elektrische-, gas- en watervoorzieningen zijn in orde en worden goed onderhouden.

> xxxDe elektrische-, gas- en watervoorzieningen zijn in orde en worden goed onderhouden.

#### 1.4 Er zijn sanitaire voorzieningen aanwezig.

Er zijn toiletten aanwezig met in de buurt een wasbak voorzien van zeep en een schone handdoek. Afhankelijk van het soort werk zijn er ook douches aanwezig.

> xxxEr zijn sanitaire voorzieningen aanwezig.

#### 1.5 Er is pauzeruimte aanwezig, met voldoende zitgelegenheid.

> xxxEr is pauzeruimte aanwezig, met voldoende zitgelegenheid.

#### 1.6 De werk- en pauzeruimten zijn rookvrij.

Per 1 januari 2004 moet elke medewerker op een rookvrije werkplek kunnen werken en pauzeren. Er is een aantal uitzonderingssituaties zoals werkruimten in de horeca, die tevens publieksruimte zijn.

> xxxDe werk- en pauzeruimten zijn rookvrij.

#### 1.7 Overal zijn de vloeren opgeruimd, egaal en stroef.

Het gaat om struikelen of uitglijden te voorkomen.Er mogen bijv. best tegels op de vloer liggen als dit maar speciale vloertegels zijn.

> xxxveral zijn de vloeren opgeruimd, egaal en stroef.

#### 1.8 Op plaatsen waar gewerkt wordt is goede verlichting aanwezig.

Iedereen moet goed kunnen lezen en zien, zonder extra inspanning.

> xxxOp plaatsen waar gewerkt wordt is goede verlichting aanwezig.

#### 1.9 Op plaatsen waar niet gewerkt wordt, zoals een trappenhuis, is verlichting aanwezig.

Het gaat hier om twee dingen:- de basisverlichting moet op een sterkte zijn dat niemand er zich onveilig voelt. Dit geldt met name in trappenhuizen;- het licht moet aan kunnen op het moment dat het nodig is.

> xxxOp plaatsen waar niet gewerkt wordt, zoals een trappenhuis, is verlichting aanwezig.

#### 1.10 Er is een ruimte waar het personeel zich kan omkleden en eigen kleding kan opbergen.

Een verkleedruimte hoeft niet in elk gebouw aanwezig te zijn.In sommige situaties zijn aparte kleedruimten voor mannen en vrouwen nodig, met name als het om grotere aantallen gaat en zijn er kluisjes nodig voor kleding en andere persoonlijke zaken.

> xxxEr is een ruimte waar het personeel zich kan omkleden en eigen kleding kan opbergen.

#### 1.11 Het gebouw is asbestvrij.

Werken met asbest is verboden.Alleen gespecialiseerde bedrijven mogen asbest verwijderen. Als er asbest aanwezig is hoeft dat geen bezwaar te zijn, zolang het maar met rust wordt gelaten. Onderhoudspersoneel moet weten op welke plekken asbest aanwezig is. Een gat boren in een wand met asbest of dat wandje verplaatsen is dan verboden.

> xxxHet gebouw is asbestvrij.

## 2 Enkele gebouwen"

#### 2.1 Er is een duidelijk onderscheid tussen publieksruimte en werkruimte.

Dit is van belang voor de veiligheid. Denk hierbij ook aan het onderscheid tussen verkeersroutes voor voertuigen en wandelroutes voor voetgangers.

> xxxEr is een duidelijk onderscheid tussen publieksruimte en werkruimte.

#### 2.2 Liften, roltrappen en elektrische deuren zijn in goede staat en worden onderhouden.

> xxxLiften, roltrappen en elektrische deuren zijn in goede staat en worden onderhouden.

#### 2.3 De liften, roltrappen en elektrische deuren hebben noodvoorzieningen bij calamiteiten.

Een voorbeeld daarvan is een noodknop voor elektrische deuren voor het geval de stroom uitvalt.

> xxxe liften, roltrappen en elektrische deuren hebben noodvoorzieningen bij calamiteiten.

#### 2.4 Trappen en bordessen zijn goed onderhouden en hebben leuningen.

Er liggen geen loszittende delen op de traptreden en de bordessen en de leuningen zitten goed vast.

> xxxTrappen en bordessen zijn goed onderhouden en hebben leuningen.

#### 2.5 De keuken wordt goed schoongemaakt.

Daaronder valt ook het tijdig vervangen van frituurvet en het schoonmaken van ovens.Voor restaurants gelden speciale regels (HACCP).

> xxxe keuken wordt goed schoongemaakt.

#### 2.6 In de keuken worden dranken en etenswaren op de juiste manier bereid en bewaard.

Voedsel staat afgedekt in een goed werkende koelkast; mogelijk lekkend voedsel staat in een schaal onderin. Er wordt gewerkt met schoon materiaal.Voor de horeca gelden bijzondere regels.

> xxxn de keuken worden dranken en etenswaren op de juiste manier bereid en bewaard.

#### 2.7 De keuken is zo ingericht dat er gladde wanden, vloeren en werkoppervlakten zijn die goed kunnen worden schoongemaakt.

Als de vloeren zijn betegeld is dat gebeurd met speciale vloertegels, waardoor het gevaar van uitglijden beperkt wordt.Voor de horeca gelden speciale richtlijnen.

> xxxDe keuken is zo ingericht dat er gladde wanden, vloeren en werkoppervlakten zijn die goed kunnen worden schoongemaakt.

## 3 Opslag / magazijn"

#### 3.1 De opslag of het magazijn wordt goed onderhouden.

Onder onderhoud wordt verstaan schoon en opgeruimd. Opruimen heeft ook te maken met een vrije vloerruimte zodat struikelgevaar wordt voorkomen.

> xxxe opslag of het magazijn wordt goed onderhouden.

#### 3.2 Stellingen en kasten worden volgens de voorschriften ingepakt.

De leverancier van de stellingen en kasten kan informatie verstrekken over de maximale belasting van de legborden en over eventuele aanvullende voorschriften.

> xxxStellingen en kasten worden volgens de voorschriften ingepakt.

#### 3.3 Stellingen en kasten zijn zo geplaatst dat zij niet kunnen omvallen.

De leverancier van de stellingen en kasten kan over plaatsingsvoorschriften informatie verstrekken. Stellingen zijn bijv. altijd voorzien van schoorbanden. Smalle en hoge stellingen moeten bijv. aan de bovenzijde ook worden vastgemaakt. Dat is zeker belangrijk als er regelmatig alleen boven in goederen liggen of als er botsgevaar door bijv. heftrucks mogelijk is.

> xxxStellingen en kasten zijn zo geplaatst dat zij niet kunnen omvallen.

#### 3.4 De vloer beschikt over voldoende draagvermogen.

Het draagvermogen dient minimaal gelijk te zijn aan:- de kast of stelling- de goederen die erop geplaatst kunnen worden;- de eventueel gebruikte transportmiddelen met daarop de goederen die op dat moment vervoerd worden.

> xxxDe vloer beschikt over voldoende draagvermogen.

#### 3.5 Als er een trap nodig is om verantwoord bij de goederen te kunnen, dan is deze aanwezig.

In een kleine opslagruimte, zoals een archief bij een kantoor, is het werken met een trap vaak afdoende.

> xxxAls er een trap nodig is om verantwoord bij de goederen te kunnen, dan is deze aanwezig.

#### 3.6 Als er transportmiddelen of hulpmiddelen worden gebruikt voor het laden en lossen van goederen, dan zijn de gangpaden voldoende breed.

Magazijnheftrucks en andere typen transportmiddelen moeten de ruimte hebben om te kunnen rijden en draaien. Die ruimte betreft de omvang van het transportmiddel plus de omvang van het te verplaatsen materiaal.

> xxxAls er transportmiddelen of hulpmiddelen worden gebruikt voor het laden en lossen van goederen, dan zijn de gangpaden voldoende breed.

## 4 Kantoorwerk"

#### 4.1 Na 2 uur computerwerk kan er minimaal 15 minuten gepauzeerd worden of kan er tijdelijk ander werk worden gedaan.

Voor het voorkomen van eenzijdige lichamelijke belasting (RSI) is pauzeren een mogelijkheid, maar afwisseling tussen verschillende taken is beter zoals telefoneren of kopiëren.

> xxxa 2 uur computerwerk kan er minimaal 15 minuten gepauzeerd worden of kan er tijdelijk ander werk worden gedaan.

#### 4.2 Bij minimaal 2 uur aaneengesloten computerwerk kan de werkplek aan de lengte van de medewerker worden aangepast.

Dit risico is nog niet beoordeeld.

Als iemand langer dan 2 uur in dezelfde houding werkt, dan geldt dat:. de stoel instelbaar is en eventueel het werkblad;. dat het beeldscherm op 60 cm afstand gezet kan worden.

#### 4.3 Spiegeling van verlichting in beeldschermen is afwezig.

Dit risico is nog niet beoordeeld.

Onbeschermde t.l.-buizen spiegelen altijd. Plaats beschermde t.l.-verlichting in de lengterichting op het beeldscherm: er ontstaat als het ware een kruis tussen verlichting en bureaulengte.

#### 4.4 Het beeldscherm staat haaks op het raam en zo mogelijk 3 meter van het raam af.

Dit risico is nog niet beoordeeld.

Dit heeft onder meer te maken met de spiegeling in het beeldscherm. Dat kost extra inspanning.

#### 4.5 Alle kantoorstoelen zijn instelbaar.

Dit risico is nog niet beoordeeld.

De hoogte, het zitvlak en de rugleuning zijn instelbaar en de rugleuning heeft een lendensteun. De armleuningen zijn instelbaar en hebben een korte armsteun.

#### 4.6 Er is een voldoende grote werktafel aanwezig en deze is eventueel in hoogte verstelbaar.

Dit risico is nog niet beoordeeld.

Voldoende groot is minimaal 120 cm bij 60 cm, maar het liefst dieper. Dieper omdat er meestal een beeldscherm en toetsenbord op staat en een beeldscherm moet weer op 60 cm. afstand van een werknemer staan. In hoogte verstelbare tafels zijn geschikt voor medewerkers met verschillende lengtes. Zorg er voor dat in hoogte verstelbare tafels door de medewerker zelf kunnen worden bijgesteld, door bijvoorbeeld een handeltje. Anders moet telkens de technische dienst worden ingeschakeld.

#### 4.7 Er is voor kleinere mensen een in hoogte verstelbaar voetenbankje aanwezig.

Dit risico is nog niet beoordeeld.

#### 4.8 Iedereen weet hoe hij zijn werkplek op de goede hoogte moet instellen.

Dit risico is nog niet beoordeeld.

Voor een goede werkhouding kan minimaal de stoel worden ingesteld en kan (als dat van toepassing is) het werkblad en het voetenbakje in hoogte worden ingesteld.

#### 4.9 Per medewerker is 8 m2ruimte aanwezig.

Dit risico is nog niet beoordeeld.

#### 4.10 Er is voldoende opbergruimte.

Dit risico is nog niet beoordeeld.

Bij voldoende opbergruimte hoeven de vloeren en bureaus niet gebruikt te worden als (tijdelijke) opslag.

#### 4.11 Printers en kopieermachines staan uit de buurt van de medewerkers.

Dit risico is nog niet beoordeeld.

In verband met geluid (en bij oudere typen ook ozon) en de opwarming van de werkruimte. Het liefst staan deze apparaten in een andere ruimte, met als voordeel dat er voor printen en kopiëren gelopen moet worden. Dit lopen onderbreekt het langdurig in dezelfde houding werken en zorgt voor een goede doorbloeding van het lichaam.

#### 4.12 Alle snoeren en kabels zijn netjes weggewerkt.

Dit risico is nog niet beoordeeld.

#### 4.13 De temperatuur is goed te regelen.

Dit risico is nog niet beoordeeld.

Door een thermostaat en door het kunnen openen van ramen.

#### 4.14 In het kantoor zijn ramen aanwezig waardoor het daglicht naar binnenkomt.

Dit risico is nog niet beoordeeld.

#### 4.15 Indien noodzakelijk is goede zonwering aanwezig.

Dit risico is nog niet beoordeeld.

Bij ramen waar veel zon door schijnt is zonwering nodig. Dat voorkomt extra opwarming van de ruimte, en spiegeling in beeldschermen.

## 5 Aan- en afvoer van materiaal"

## 6 Lichamelijk werk"

## 7 Werken op locatie"

## 8 Werken met klanten / cliënten / gasten"

#### 8.1 Er zijn afspraken gemaakt over wat te doen als een klant agressief reageert.

Dit risico is nog niet beoordeeld.

Het gaat hier om agressie en geweld van klanten/cliënten/patiënten/gasten naar het eigen personeel. Hieronder wordt ook verstaan seksuele intimidatie, vandalisme en discriminatie.

#### 8.2 Deze afspraken zijn bij medewerkers en klanten bekend.

Dit risico is nog niet beoordeeld.

Door het maken van afspraken (op papier) kunnen medewerkers grenzen stellen en weten klanten wat niet wordt toegestaan.

#### 8.3 Medewerkers kunnen eenvoudig hulp inroepen of alarm slaan in geval van nood.

Dit risico is nog niet beoordeeld.

Bijvoorbeeld via een naaste collega of via een telefoon in de directe nabijheid.

#### 8.4 Er zijn afspraken over de opvang van medewerkers die met ongewenst gedrag worden geconfronteerd.

Dit risico is nog niet beoordeeld.

#### 8.5 Er is een klachtenregeling opgesteld voor klanten.

Dit risico is nog niet beoordeeld.

## 9 Geluid"

## 10 Klimaat: warmte, straling, koude, buiten"

## 11 Trillingen"

## 12 Gevaarlijke stoffen als grondstof"

## 13 Gevaarlijke stoffen door / tijdens het werk"

## 14 Hoogtes / kruipruimtes / besloten ruimtes"

## 15 Gereedschappen / machines / transportmiddelen"

## 16 In geval van nood"

#### 16.1 Nooduitgangen zijn duidelijk aangegeven en zijn vrij toegankelijk.

Dit risico is nog niet beoordeeld.

Zonder dat er iets verschoven hoeft te worden of zonder dat er een sleutel gehaald hoeft te worden, kan de nooduitgang meteen geopend worden.

#### 16.2 Bij grotere gebouwen is met een plattegrond aangegeven waar men zich bevindt en welke vluchtroutes gebruikt kunnen worden.

Dit risico is nog niet beoordeeld.

Op diverse plekken is goed zichtbaar een plattegrond opgehangen waar medewerkers kunnen zien waar ze nu zijn en waar in geval van nood de nooduitgangen zich bevinden. Er wordt een wenselijke looproute naar de uitgang aangegeven.

#### 16.3 Alle medewerkers kennen de vluchtroutes en nooduitgangen

Dit risico is nog niet beoordeeld.

Dit geldt zowel voor de vaste werklocatie als voor de locatie waarop op dat moment gewerkt wordt.Doordat medewerkers zichzelf kunnen redden, kunnen de gevolgen bij calamiteiten beperkt blijven.

#### 16.4 Het alarm of het noodsignaal is overal hoorbaar.

Dit risico is nog niet beoordeeld.

Als er met gehoorbescherming op wordt gewerkt is het verstandig een ander type signaal te geven, bijv. een lichtsignaal.In bijvoorbeeld een kleinere winkel zal geen noodsignaal aanwezig, tenzij er een brandmelder aanwezig is.

#### 16.5 Op elk telefoontoestel staat een alarmnummer.

Dit risico is nog niet beoordeeld.

In kleinere bedrijven zal dat het nummer 112 zijn. Bij grotere bedrijven zal dat een intern alarmnummer zijn dat of op de telefoon vermeld staat of bij iedereen bekend is.

#### 16.6 Er wordt minstens één keer per jaar een ontruimingsoefening gehouden.

Dit risico is nog niet beoordeeld.

Hiermee controleert u of de afspraken, zoals het verzamelen van alle medewerkers op de afgesproken plek, bekend zijn en of deze worden opgevolgd.In bijvoorbeeld een kleine winkel zal dat niet nodig zijn.

#### 16.7 Er zijn voldoende bedrijfshulpverleners aanwezig.

Dit risico is nog niet beoordeeld.

Op een locatie tot 50 werknemers is er minimaal 1 bedrijfshulpverlener (BHV-er) aanwezig. Op een locatie tot 250 werknemers is er tenminste 1 per 50 werknemers aanwezig. Bij het aantal werknemers moet het aantal bezoekers/cliënten/patiënten worden opgeteld.

#### 16.8 De bedrijfshulpverleners hebben een adequate opleiding gevolgd.

Dit risico is nog niet beoordeeld.

Een BHV-er moet eerste hulp kunnen verlenen, een beginnende brand kunnen bestrijden, een ontruiming kunnen begeleiden. De specifieke eisen van een BHV-er zijn afhankelijk van de risico's in het bedrijf.

#### 16.9 Er is een bedrijfshulpverleningsplan gemaakt.

Dit risico is nog niet beoordeeld.

Op basis van dit plan en het goed functioneren ervan is de werkgever of de BHV-er degene die bij bijv. brand zeker weet of de brandweer nog naar mogelijke slachtoffers moet zoeken en welke wegen de brandweer kan volgen aan de hand van de plattegrond.Het plan bevat onder meer wie de leiding geeft aan de BHV, wie de BHV-ers zijn, dienstroosters van de BHV-ers, plattegronden van het bedrijf met daarop aangegeven vluchtwegen, de plaats van de blusmiddelen, verzamelplaatsen van de mensen die het pand verlaten, eventuele plattegronden voor de brandweer.

#### 16.10 Er is een bedrijfsnoodplan gemaakt.

Dit risico is nog niet beoordeeld.

Als kleine incidenten kunnen leiden tot calamiteiten voor het gehele bedrijf en de omgeving, dan is het nodig een bedrijfsnoodplan te maken.

#### 16.11 Er zijn voldoende en juiste blusmiddelen.

Dit risico is nog niet beoordeeld.

Er zijn blusmiddelen op basis van poeder, kooldioxide en schuim en brandslangen voor water. Welk blusmiddel het juiste is, is afhankelijk van de risico's in het bedrijf.

#### 16.12 Er is een onderhoudscontract met de leverancier van blusmiddelen.

Dit risico is nog niet beoordeeld.

Vraag bij uw leverancier hoe vaak bijv. het blusapparaat moet worden gecontroleerd op juiste werking.

#### 16.13 Er zijn op voldoende plekken EHBO-middelen aanwezig.

Dit risico is nog niet beoordeeld.

#### 16.14 De EHBO-middelen worden regelmatig gecontroleerd op houdbaarheid en volledigheid.

Dit risico is nog niet beoordeeld.

## 17 Werk- en rusttijden"

#### 17.1 Een werkdag is maximaal 9 uur.

Dit risico is nog niet beoordeeld.

In de Arbeidstijdenwet staan regels over de lengte van een werkdag, een werkweek en pauzes. Dit zijn de standaardregels. In een CAO of door overleg met de ondernemingsraad of de personeelsvertegenwoordiging kunnen andere regels zijn afgesproken. Deze afwijkingen op de standaardregeling worden schriftelijk vastgelegd.

#### 17.2 Een werkweek is maximaal 45 uur en de gemiddelde werktijd binnen 13 weken is maximaal 40 uur per week.

Dit risico is nog niet beoordeeld.

#### 17.3 De pauzetijden voldoen aan de voorschriften.

Dit risico is nog niet beoordeeld.

Als er langer dan:- 5,5 uur gewerkt wordt dan is er een pauze van 30 minuten aaneengesloten;- 8 uur gewerkt wordt dan is de pauze minstens 45 minuten, waarvan 30 minuten aaneengesloten

#### 17.4 De afwijkende regels voor jongeren onder 18 jaar worden toegepast.

Dit risico is nog niet beoordeeld.

Jongeren mogen bijv. niet ’s nachts werken en niet overwerken.

#### 17.5 De afwijkende regels voor zwangeren en pas bevallen vrouwen worden toegepast.

Dit risico is nog niet beoordeeld.

Deze regels gaan over niet ’s nachts werken, niet overwerken en tijd krijgen om te zogen.

#### 17.6 Als er in ploegendienst wordt gewerkt, dan wordt een ploegensysteem gebruikt dat zo min mogelijk gezondheidsschade toebrengt.

Dit risico is nog niet beoordeeld.

Vaak zullen er in de CAO al afspraken staan om gezondheidsschade zoals hartritmestoornissen en slaapstoornissen te voorkomen. Belangrijke regels voor een goed ploegensysteem zijn:- het draaien van voorwaartse diensten: van de ochtend, naar de middag, naar de avond, naar de nacht, naar de ochtend, etc.;- het niet te lang draaien van één soort dienst: bijv. niet een week lang een nachtdienst.

## 18 Taken / functies van medewerkers"

#### 18.1 Medewerkers verrichten zo min mogelijk repeterend werk en kunnen zelf het tempo bepalen.

Dit risico is nog niet beoordeeld.

Repeterend werk is werk waarbij in een korte tijd dezelfde handeling alsmaar wordt herhaald. Bij dat soort werk kan slijtage van spieren, pezen, gewrichten optreden met als gevolg verzuim.Een ander belangrijk effect is de afname van motivatie en inzet. Medewerkers die meer dan alleen uitvoerende taken hebben zijn geneigd om met het bedrijf mee te denken.

#### 18.2 Taken van medewerkers zijn afgestemd op datgene wat zij kunnen.

Dit risico is nog niet beoordeeld.

Dit betekent dat medewerkers passend werk hebben: niet te moeilijk en niet te makkelijk. Hierdoor raken medewerkers niet over- of onderbelast.

#### 18.3 Er wordt bij het verdelen van taken aandacht besteed aan kwetsbare groepen.

Dit risico is nog niet beoordeeld.

Onder kwetsbare groepen vallen oproepkrachten, uitzendkrachten, onervaren krachten (nieuwkomers), gehandicapten, jongeren onder de 18 jaar, zwangere vrouwen en medewerkers die de Nederlandse taal niet beheersen.Deze groepen zijn kwetsbaar omdat ze bijv. of minder goed op de hoogte zijn van de regels of door bijv. zwangerschap bepaald soort werk niet kunnen doen.

#### 18.4 Medewerkers kunnen binnen hun taken zelf beslissingen nemen.

Dit risico is nog niet beoordeeld.

Het zelf beslissingen mogen nemen, geeft controle over het eigen werk en biedt uitdaging om het te verbeteren en er van te leren.

#### 18.5 Als er problemen zijn in het werk, kunnen medewerkers dit in overleg met collega’s of met de leiding oplossen.

Dit risico is nog niet beoordeeld.

Het zo snel mogelijk kunnen oplossen van problemen is belangrijk. Problemen, die onopgelost blijven, kunnen werkdruk veroorzaken.

#### 18.6 Als er problemen zijn met het werk van andere afdelingen, dan kunnen medewerkers dit bespreken en oplossen.

Dit risico is nog niet beoordeeld.

Zelf of in overleg met de leiding initiatief kunnen nemen voor het oplossen van problemen is uitdagend en leert medewerkers verantwoordelijk en zelfstandig te werken.

#### 18.7 Medewerkers krijgen informatie over hun functioneren en wat hun werk voor het bedrijf oplevert.

Dit risico is nog niet beoordeeld.

Weten wat de bijdrage is van de werkzaamheden aan het totaalresultaat motiveert.

## 19 Ongewenst gedrag van medewerkers"

#### 19.1 Er zijn afspraken gemaakt over ongewenste gedragingen van medewerkers onderling.

Dit risico is nog niet beoordeeld.

Ongewenst gedrag gaat over (seksuele) intimidatie, pesten, agressie en geweld, discriminatie, en gebruik van alcohol en drugs.

#### 19.2 Alle medewerkers kennen deze afspraken.

Dit risico is nog niet beoordeeld.

Bij die afspraken (op papier) wordt ook aandacht besteed aan de eventuele sancties als iemand zich niet aan de regels houdt.

#### 19.3 Er is een vertrouwenspersoon in het bedrijf aanwezig.

Dit risico is nog niet beoordeeld.

Eén van de collega's in het bedrijf kan de vaste vertrouwenspersoon zijn. Het kunnen praten over onzekerheid als gevolg van ongewenst gedrag en het krijgen van hulp bij het bespreekbaar maken ervan met de ‘dader’, voorkomt dat seksuele intimidatie lang voortduurt en helpt om ongewenst gedrag te snel te stoppen.

#### 19.4 Er is naast de vertrouwenspersoon een tweede persoon aangewezen om iemand te helpen een klacht in te dienen als het ongewenste gedrag blijft doorgaan.

Dit risico is nog niet beoordeeld.

Als ongewenst gedrag niet stopt, dan is er een klachtenregeling. Het ‘slachtoffer’ kan zijn beklag doen, de ‘dader’ wordt gehoord en de regeling leidt tot maatregelen. Een maatregel kan zijn dat bij gegronde klachten de ‘dader’ wordt ontslagen.Die tweede persoon mag ook iemand buiten het eigen bedrijf zijn, bijv. iemand van de Arbodienst.

## 20 Basisafspraken over arbo"

#### 20.1 Bij de inkoop van materialen wordt gelet op arbo-eisen.

Dit risico is nog niet beoordeeld.

Vooraf rekening houden met de arbo-eisen voorkomt in een later stadium kosten. Voorbeelden zijn:- geluidsarme machines zodat geen gehoorbescherming gekocht en gedragen hoeft te worden;- makkelijk in hoogte verstelbaar bureaus zodat kortere en langere mensen er aan kunnen werken;- stoffen in het productieproces die afzuiging nodig hebben en hoge milieu-eisen stellen, vervangen door stoffen met hetzelfde productie-effect en met minder gebruikseisen.

#### 20.2 Bij nieuwbouw en verbouw en bij de (her)inrichting van werkplekken wordt rekening gehouden met arbo-eisen.

Dit risico is nog niet beoordeeld.

Bijvoorbeeld bij die plekken in het bedrijf waar het aantal ongevallen hoog is, worden de oorzaken meteen meegenomen in de verbouwingsplannen zodat die situaties niet meer kunnen ontstaan.

#### 20.3 Bij het samenstellen van functies wordt eenzijdige belasting voorkomen.

Dit risico is nog niet beoordeeld.

Eenzijdige belasting kan zowel lichamelijk of geestelijk zijn. Voorkoming van geestelijke belasting kan door:- niet alleen routinematig werk uit te voeren;- afwisseling met moeilijkere taken zoals planning van het werk;- zelf of in samenwerking met anderen problemen kunnen oplossen.

#### 20.4 Arboknelpunten worden zo snel mogelijk opgelost en de oorzaak wordt bekeken.

Dit risico is nog niet beoordeeld.

Aanpak van de oorzaken voorkomt nieuwe of andere problemen.

#### 20.5 In werkbesprekingen wordt regelmatig gesproken over arbeidsomstandigheden en verzuim.

Dit risico is nog niet beoordeeld.

Door arbo en verzuim regelmatig te bespreken kunnen er gericht oplossingen gezocht worden en wordt er voortdurend gewerkt aan de verbetering van arbo.

#### 20.6 Over arbo wordt gesproken met het personeel, de personeelsvertegenwoordiging of de ondernemingsraad.

Dit risico is nog niet beoordeeld.

In de Arbowet en de Wet op de Ondernemingsraden staat dat afspraken gemaakt moeten worden over onder meer:- de risico-inventarisatie en -evaluatie, de rapportage en het plan van aanpak;- de verzuimregels;- de inschakeling van de Arbodienst;- de inschakeling van bedrijfshulpverleners.Een ondernemingsraad is verplicht vanaf 50 werknemers. Tussen 10 en 50 werknemers kan de werkgever vrijwillig een personeelsvertegenwoordiging instellen. Als de meerderheid van de werknemers dat wil, dan moet de werkgever een personeelsvertegenwoordiging instellen.Bij minder dan 10 werknemers kan de werkgever uit vrije wil een personeelsvertegenwoordiging instellen.Als er geen medezeggenschapsorgaan is, dan wordt het overleg met de belanghebbende werknemers.

## 21 Voorlichting"

#### 21.1 Iedere werknemer kan het RI&E-rapport inzien.

Dit risico is nog niet beoordeeld.

Door het rapport in te zien, kunnen werknemers leren met welke risico’s zij te maken hebben en daardoor veiliger gaan werken.

#### 21.2 Medewerkers ontvangen regelmatig voorlichting en instructie over het (veilig) uitvoeren van hun werk

Dit risico is nog niet beoordeeld.

Per functie is vastgesteld hoe het werk gedaan moet worden en met welke hulpmiddelen. Daarbij wordt ook ingegaan op persoonlijke beschermingsmiddelen.

#### 21.3 Kwetsbare groepen krijgen extra aandacht bij de voorlichting en instructies.

Dit risico is nog niet beoordeeld.

Onder kwetsbare groepen vallen oproepkrachten, uitzendkrachten, onervaren krachten (nieuwkomers), gehandicapten, jongeren onder de 18 jaar, zwangere vrouwen en medewerkers die de Nederlandse taal niet beheersen. Deze groepen zijn kwetsbaar omdat ze of minder goed op de hoogte zijn van de regels of door bijv. zwangerschap bepaald soort werk niet kunnen doen. De voorlichting geldt voor iedereen dus ook voor diegenen die werkzaamheden verrichten als schoonmaak- en schilderwerk.

#### 21.4 Werkgevers van ingeleende werknemers hebben een exemplaar van het RI&E-rapport.

Dit risico is nog niet beoordeeld.

Dit hoeft niet het hele rapport te zijn, maar wel dat onderdeel dat te maken heeft met werk van de ingeleende werknemer. De uitlenende werkgever kan op die manier zorgen dat hij een werknemer stuurt die voldoende opgeleid is. De inlenende werkgever weet dat hij deskundig personeel krijgt dat makkelijk voor te lichten en te instrueren is.

#### 21.5 Medewerkers voeren de instructies uit.

Dit risico is nog niet beoordeeld.

De instructies zijn er niet voor niks. Dat betekent dat medewerkers ze ook op moeten volgen.

#### 21.6 Er wordt op toegezien dat iedereen zijn werk op een juiste en veilige manier doet.

Dit risico is nog niet beoordeeld.

Dat kan de leidinggevende doen, maar ook collega's kunnen elkaar daarbij helpen. Het toezicht houden gaat ver. Om aansprakelijkheid te kunnen ontlopen moet een werkgever kunnen aantonen dat hij er alles aangedaan heeft om een ongeval te voorkomen. Dit betekent dat de medewerkers weten wat de risico’s zijn, hoe ze daarmee moeten omgaan en dat ze verplicht zijn (arbo)instructies op te volgen.

#### 21.7 De leidinggevende geeft zelf het goede voorbeeld en spreekt werknemers aan op onveilig gedrag.

Dit risico is nog niet beoordeeld.

#### 21.8 Er zijn afspraken gemaakt over wat te doen als iemand zich niet aan de arboregels houdt.

Dit risico is nog niet beoordeeld.

Als iemand zijn taken niet goed uitvoert zijn er (sanctie)maatregelen afgesproken. Het opvolgen van arboinstructies is in het belang van de medewerker zelf (bescherming), in het belang van zijn omgeving, en in het belang van de werkgever (o.a. aansprakelijkheid).

## 22 Afspraken over verzuim"

#### 22.1 Er zijn afspraken gemaakt over hoe, wanneer en bij wie medewerkers zich ziek moeten melden.

Dit risico is nog niet beoordeeld.

Bijv. een medewerker moet zich telefonisch voor 9 uur bij de leidinggevende ziek melden.

#### 22.2 Er zijn afspraken gemaakt over wie de zieke begeleidt en op welke manier.

Dit risico is nog niet beoordeeld.

Het is bekend wie er wanneer contact opneemt met de zieke, en hoe de terugkeer wordt geregeld.

#### 22.3 Voor werknemers die langer dan 6 weken ziek zijn wordt een reïntegratieplan gemaakt.

Dit risico is nog niet beoordeeld.

De Wet Verbetering Poortwachter schrijft dit voor.

#### 22.4 Het verzuim wordt geregistreerd.

Dit risico is nog niet beoordeeld.

Als het verzuim bij een verzekeringsmaatschappij is verzekerd, is het mogelijk dat ook de maatschappij eisen stelt aan de registratie.

#### 22.5 Er wordt naar de oorzaken van verzuim gekeken.

Dit risico is nog niet beoordeeld.

Het achterhalen van de oorzaken kan helpen het verzuim te verminderen.

#### 22.6 Alle afspraken zijn vastgelegd, zodat iedereen weet wat hij wanneer moet doen.

Dit risico is nog niet beoordeeld.

Het vastleggen van afspraken voorkomt onduidelijkheden en is verplicht bij bijv. reïntegratie.

#### 22.7 De ondernemingsraad of de personeelsvertegenwoordiging is betrokken geweest bij de afspraken over verzuim

Dit risico is nog niet beoordeeld.

## 23 Ongevallen"

#### 23.1 Ongevallen worden geregistreerd en de oorzaken onderzocht.

Dit risico is nog niet beoordeeld.

Het registreren van ongevallen en het bekijken van de oorzaken vormen de basis voor het nemen van gerichte maatregelen om deze ongevallen in de toekomst te voorkomen.

#### 23.2 Het register geeft aan welke maatregelen zijn genomen om deze ongevallen te voorkomen.

Dit risico is nog niet beoordeeld.

Omdat er al ongevallen zijn gebeurd is het nodig maatregelen te treffen zodat ze niet weer kunnen gebeuren.

#### 23.3 Ongevallen met ernstige gevolgen worden meteen gemeld bij de Arbeidsinspectie.

Dit risico is nog niet beoordeeld.

Onder een “ernstig ongeval” wordt verstaan lichamelijk of geestelijk letsel dat binnen 24 uur leidt tot opname in een ziekenhuis of letsel dat de dood tot gevolg heeft. De Arbeidsinspectie verricht dan een ongevalsonderzoek.

## 24 Voortgang van het plan van aanpak"

#### 24.1 Elk jaar wordt over de uitvoering van het plan van aanpak gerapporteerd.

Dit risico is nog niet beoordeeld.

Jaarlijks moet de voortgang van het plan van aanpak op schrift worden gezet. Die voortgang wordt besproken met de ondernemingsraad, de personeelsvertegenwoordiging of het personeel.

#### 24.2 Oorzaken van verzuim en ongevallen worden betrokken bij de voortgangsbespreking. meegenomen.

Dit risico is nog niet beoordeeld.

Het is handig om dat te doen, want deze oorzaken kunnen van invloed zijn op de volgorde van onderwerpen of leiden tot nieuwe onderwerpen.

#### 24.3 De RI&E is actueel.

Dit risico is nog niet beoordeeld.

Een RIE is niet meer actueel als er zich bijvoorbeeld veranderingen hebben voorgedaan. Voorbeelden van verandering zijn gewijzigde manieren van werken of technische vernieuwingen, zoals:- de inrichting van een nieuwe productielijn;- uitbreiding van het dienstenpakket;- een ingrijpende verbouwing;- een ingrijpende wijziging van taken van medewerkers.Bij een kleine verandering is een gedeeltelijk vernieuwing van de RI&E, voor dat deel van het bedrijf dat veranderd is, vaak voldoende.

## 25 Organisatie van de preventie"

### 25.1 Preventietaken"

#### 25.1.1 De organisatie heeft de preventietaken toegewezen

Dit risico is nog niet beoordeeld.

Een werkgever met méér dan 15 medewerkers moet preventietaken toewijzen aan één of meer werknemers. Een werkgever met ten hoogste 15 medewerkers mag de preventietaken zelf uitvoeren. De werkgever hoeft geen speciale medewerker aan te trekken met preventietaken. Preventie kan een onderdeel zijn van de taak van de werkgever zelf of van de taak van één of meer werknemers. Voor het gemak wordt echter in dit instrument steeds gesproken over preventiemedewerker.

Preventietaken zijn: het meewerken aan of het opstellen van een RI&E, uitvoeren van de maatregelen uit het plan van aanpak, het geven van voorlichting, het signaleren van risico's en het treffen van maatregelen tegen die risico’s.

De preventiemedewerkers (het aantal hangt af van preventietaken en de gewenste organisatie) hebben de kennis en ervaring, de middelen en de tijd, zodat zij de werkgever goed kunnen bijstaan bij de preventietaken. De preventiemedewerker werkt hierbij samen met de OR, de personeelsvertegenwoordiging of de medewerkers die het betreft.

Werkgevers die hun preventietaken goed uitvoeren besparen doorgaans aanzienlijk op de kosten van ongevallen, verzuim en stressproblemen. Investeringen in arbeidsomstandigheden en in het personeel renderen meestal goed als het gaat om de sfeer en productiviteit van het bedrijf.

#### 25.1.2 De preventiemedewerker werkt mee aan het opstellen van de RI&E

Dit risico is nog niet beoordeeld.

Dit is één van de activiteiten die een medewerker met preventietaken dient uit te voeren. Bij het ontbreken van een actuele RI&E is de werkgever verantwoordelijk en spreekt de Arbeidsinspectie deze aan.

#### 25.1.3 De preventiemedewerker helpt mee met het uitvoeren van het plan van aanpak

Dit risico is nog niet beoordeeld.

Ook dit is één van de activiteiten die een medewerker met preventietaken dient uit te voeren. Het kan bijvoorbeeld gaan om het geven van voorlichting over het onderhoud van apparaten of over het veilig werken met gevaarlijke stoffen.

#### 25.1.4 De preventiemedewerker ondersteunt werkgever, OR, PVT of werknemers over de te nemen preventiemaatregelen

Dit risico is nog niet beoordeeld.

De preventiemedewerker heeft een onafhankelijke en zelfstandige positie ten opzichte van de werkgever, de OR of PVT en de werknemers.De overheid geeft de preventiemedewerker arbeidsrechtelijke bescherming in het kader van de uitvoering van preventietaken. De preventiemedewerker heeft ontslagbescherming vergelijkbaar met een OR-lid.

#### 25.1.5 De preventiemedewerker kent de arborisico’s in het bedrijf en weet hoe hij/zij de risico’s kan voorkomen

Dit risico is nog niet beoordeeld.

- Van belang is dat de preventiemedewerker(s) voldoende deskundigheid hebben om de concrete maatregelen uit het Plan van Aanpak te kunnen (laten) uitvoeren. Hoewel de wet niet expliciet aangeeft waaraan een preventiemedewerker moet voldoen, lijkt het logisch dat een werknemer over de volgende minimale vaardigheden beschikt:
- het kunnen verstrekken van informatie en het geven van voorlichting;
- de bekendste arbeidsrisico’s in de branche kennen en deze in het bedrijf kunnen herkennen;
- het kennen van verbetermogelijkheden en deze in het bedrijf ook voorstellen;
- arbomaatregelen kunnen (laten) uitvoeren.

De ingevulde RI&E kan aanwijzingen geven over de nodige aanvullende deskundigheid. Voor inhoudelijke aanvullende ondersteuning kan de medewerker met preventietaken de werkgever adviseren interne of externe arbo-expertise inhuren.

### 25.2 Maatwerkregeling/Vangnetregeling"

#### 25.2.1 U laat zich bij uw preventietaken bijstaan door één of meer gecertificeerde deskundigen (maatwerkregeling) of door een gecertificeerde arbodienst (vangnetregeling)

Dit risico is nog niet beoordeeld.

Op grond van de Arbowet moet de werkgever zich bij de uitvoering van de volgende taken laten bijstaan door één of meer gecertificeerde deskundigen:

- toetsing en advisering in het kader van de risico-inventarisatie en -evaluatie;
- arbeidsgezondheidskundig onderzoek;
- houden van arbeidsomstandighedenspreekuur (arbeidsomstandigheden spreekuur);
- aanstellingskeuring;
- verzuimbegeleiding.

De ‘maatwerkregeling’ houdt in, dat de werkgever zelf bepaalt, op welke wijze gecertificeerde deskundigen bijstand verlenen. Concreet betekent dit dat er minimaal een contract met een gecertificeerde bedrijfsarts dient te zijn afgesloten en dat een gecertificeerde arbodeskundige de RI&E dient te toetsen, als toetsing van de RI&E noodzakelijk is. Als alternatief kan gebruik worden gemaakt van de ‘vangnetregeling’, de arbodienst verzorgt dan de bijstand.Zie ook het stroomschema op www.arbo.nl/schema voor de keuze tussen beide regelingen.

### 25.3 Maatwerkregeling"

### 25.4 Vangnetregeling"

1. Voorbereiding
2. Inventarisatie
3. Evaluatie
4. Plan van aanpak
5. Rapport

Geproduceerd door EU-OSHA | Over